Further suppress CompressedTextureFormatTest.Cube

Also flakes with ETC2 texture formats.

Bug: 362762192
Change-Id: I86b6f3d66a46a105155093c47cbcd6804565b251
Reviewed-on: https://dawn-review.googlesource.com/c/dawn/+/207554
Reviewed-by: Stephen White <senorblanco@chromium.org>
Auto-Submit: Yuly Novikov <ynovikov@chromium.org>
Commit-Queue: Stephen White <senorblanco@chromium.org>
diff --git a/src/dawn/tests/end2end/CompressedTextureFormatTests.cpp b/src/dawn/tests/end2end/CompressedTextureFormatTests.cpp
index 34f83a6..b54c9bc 100644
--- a/src/dawn/tests/end2end/CompressedTextureFormatTests.cpp
+++ b/src/dawn/tests/end2end/CompressedTextureFormatTests.cpp
@@ -755,8 +755,9 @@
 
     const wgpu::TextureFormat format = GetParam().mTextureFormat;
 
-    // TODO(crbug.com/362762192): diagnose this failure on GLES with ASTC texture formats
-    DAWN_SUPPRESS_TEST_IF(IsOpenGLES() && utils::IsASTCTextureFormat(format));
+    // TODO(crbug.com/362762192): diagnose this failure on GLES with ASTC and ETC2 texture formats
+    DAWN_SUPPRESS_TEST_IF(IsOpenGLES() && (utils::IsASTCTextureFormat(format)) ||
+                          utils::IsETC2TextureFormat(format));
 
     constexpr uint32_t kLayers = 6;
     CopyConfig config = GetDefaultSmallConfig(kLayers);